"""LucidDynamodb Library

A minimalistic wrapper to AWS DynamoDB
"""
from LucidDynamodb.operations import *